@@ -1,7 +1,7 @@
 /*
  This file is part of pybliographer
  
- Copyright (C) 1998 Frederic GOBRY
+ Copyright (C) 1998-1999 Frederic GOBRY
  Email : gobry@idiap.ch
  	   
  This program is free software; you can redistribute it and/or
@@ -18,57 +18,30 @@
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  
- $Id: stringutils.c,v 1.6 1998/10/28 13:29:13 gobry Exp $
+ $Id: stringutils.c,v 1.10 1999/05/10 11:51:13 gobry Exp $
 */
 
 #include "bibtex.h"
 
 static GList * strings = NULL;
 
-void tmp_string (char * string) {
-  strings = g_list_append (strings, string);
+gchar *
+bibtex_tmp_string (gchar * string) {
+    strings = g_list_append (strings, string);
+    return string;
 }
 
-void tmp_string_free (void) {
-  GList * tmp = strings;
+void 
+bibtex_tmp_string_free (void) {
+    GList * tmp = strings;
+    
+    while (tmp) {
+	g_free (tmp->data);
+	tmp = tmp->next;
+    }
 
-  while (tmp) {
-    g_free (tmp->data);
-    tmp = tmp->next;
-  }
-
-  g_list_free (strings);
-
-  strings = NULL;
+    g_list_free (strings);
+    
+    strings = NULL;
 }
 
-char *
-merge_strings (char * s1, char * s2)
-{
-  char * ret;
-  char * t1, *t2;
-  char b1, b2;
-
-  t1 = g_strdup (s1); 
-  t2 = g_strdup (s2);
-
-  b1 = (t1[0] == '{') ? '{' : '"';
-  b2 = (t2[0] == '{') ? '{' : '"';
-
-  t1 [strlen (t1) - 1] = '\0';
-  t2 [strlen (t2) - 1] = '\0';
-
-  if (b2 == '"') b1 = '"';
-  
-  if (b1 == '"') {
-    ret = g_strconcat ("\"", t1 + 1, t2 + 1, "\"", NULL);
-  }
-  else {
-    ret = g_strconcat ("{", t1 + 1, t2 + 1, "}", NULL);
-  }
-
-  g_free (t1);
-  g_free (t2);
-
-  return (ret);
-}
